# cr-nimble
Iterative algorithms for numerical linear algebra with JAX

[![codecov](https://codecov.io/gh/carnotresearch/cr-nimble/branch/main/graph/badge.svg?token=PX1MGTZ7VL)](https://codecov.io/gh/carnotresearch/cr-nimble) 
[![Unit Tests](https://github.com/carnotresearch/cr-nimble/actions/workflows/ci.yml/badge.svg)](https://github.com/carnotresearch/cr-nimble/actions/workflows/ci.yml)
[![Documentation Status](https://readthedocs.org/projects/cr-nimble/badge/?version=latest)](https://cr-nimble.readthedocs.io/en/latest/?badge=latest)
